This folder is empty by default, but if you have the appropriate license you can place BADA3.x files here to use BADA for aircraft performance calculations.


Extract the bada zip, i.e. `bada_3131.zip`, in the same folder as this readme file.
It will contain all `.APF`, `.OPF`, `.PTD` plus `SYNONYM.NEW` and `ReleaseSummary` files.


The Base of Aircraft Data (BADA) is an Aircraft Performance Model (APM) developed, owned and maintained by the European Organisation for the Safety of Air Navigation (EUROCONTROL) through active cooperation with aircraft manufacturers. The use of BADA is regulated by a license agreement which stipulates terms and conditions of use based on the contractual constraints EUROCONTROL is committed to with its data providers.

Outside of Eurocontrol, access to BADA data files is also given to a number of Air Navigation Service Providers, research and development organisations, universities and commercial entities, to the extent necessary to enable them to work on Air Traffic Management related projects. The use of BADA is free of charge, but limited to the kind of work/projects mentioned above.
If you feel that your organisation could use BADA and you would like to get access to it, you may wish to obtain a BADA user license, by following the instructions on the website below.

https://www.eurocontrol.int/services/bada
